==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, markType, markDep, fromEnum } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { Pool$1 } from "igniteui-react-core";
import { Rectangle } from "igniteui-react-core";
import { ArrayExtension } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var WaterfallSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeries, _super);
    function WaterfallSeries() {
        var _this = _super.call(this) || this;
        _this.ab = WaterfallSeries.$;
        return _this;
    }
    WaterfallSeries.prototype.get_eg = function () {
        return true;
    };
    WaterfallSeries.prototype.get_dy = function () {
        return true;
    };
    WaterfallSeries.prototype.get_dp = function () {
        return true;
    };
    WaterfallSeries.prototype.bv = function () {
        return new WaterfallSeriesView(this);
    };
    WaterfallSeries.prototype.lo = function (a) {
        _super.prototype.lo.call(this, a);
        this.uo = a;
    };
    WaterfallSeries.prototype.preferredCategoryMode = function (a) {
        return 2;
    };
    WaterfallSeries.prototype.get_dz = function () {
        return true;
    };
    WaterfallSeries.prototype.mc = function (a, b) {
        _super.prototype.mc.call(this, a, b);
        this.uz = a;
        this.u0 = b;
    };
    WaterfallSeries.prototype.oy = function () {
        return this.uz;
    };
    WaterfallSeries.prototype.oz = function () {
        return this.u0;
    };
    WaterfallSeries.prototype.b1 = function () {
        if (this.b2 == 0) {
            return 2;
        }
        return _super.prototype.b1.call(this);
    };
    WaterfallSeries.prototype.get_cz = function () {
        return true;
    };
    WaterfallSeries.prototype.lt = function (a, b, c, d) {
        _super.prototype.lt.call(this, a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.l7(false);
                break;
        }
    };
    WaterfallSeries.prototype.er = function (a, b) {
        if (this.eu(a, b)) {
            return true;
        }
        if (this.p3(a, b)) {
            return true;
        }
        return false;
    };
    WaterfallSeries.prototype.pk = function (a) {
        var _this = this;
        if (this.uo == null || this.uo.db == null || this.uo.db.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        var b = this.uo.db;
        var c = this.o6(a);
        var d = -1;
        var e = this.xAxis.cf;
        var f = this.po.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.uo.di(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.uo.di(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        var g = d;
        var h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        var i = this.u1(g);
        var j = this.u1(d);
        var k = this.u1(h);
        var l = i.left + i.width / 2;
        var m = j.left + j.width / 2;
        var n = k.left + k.width / 2;
        var o = Math.abs(l - c.x);
        var p = Math.abs(m - c.x);
        var q = Math.abs(n - c.x);
        var r = i.containsPoint(c);
        var s = j.containsPoint(c);
        var t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    };
    WaterfallSeries.prototype.u1 = function (a) {
        return this.uo.dh(a);
    };
    WaterfallSeries.prototype.rm = function () {
        return 1;
    };
    WaterfallSeries.prototype.ko = function (a, b) {
        _super.prototype.ko.call(this, a, b);
        this.uo.db.count = 0;
    };
    WaterfallSeries.prototype.get_tf = function () {
        return 1;
    };
    WaterfallSeries.prototype.f3 = function () {
        return this.t5.ky(this.by.bv, this.by.bu, this.getEffectiveViewport1(this.by));
    };
    WaterfallSeries.prototype.su = function (a, b) {
        var c = b;
        _super.prototype.su.call(this, a, b);
        var d = b.bv;
        var e = b.bu;
        var f = this.getEffectiveViewport1(b);
        var g = this.t5.ky(d, e, f);
        var h = this.up;
        var i = this.uq;
        var j;
        var k = this.td(b);
        var l = NaN;
        var m = c.db;
        var n;
        var o = 0;
        this.rk.a0(this, this.r4(), runOn(this, this.q5), this.sc(b), this.sd(b));
        this.rk.r = this.up;
        this.rk.s = this.uq;
        this.rk.k = this.up;
        this.rk.l = this.uq;
        var p = false;
        var q = this.rk.b;
        if (q != null) {
            p = true;
        }
        var r = this.t5.ck;
        var s = this.valueColumn.count;
        var t = a.f;
        var u = this.t5;
        var v = new ScalerParams(0, d, e, this.t5.cf, f);
        var w = this.oo;
        var x = this.uz;
        var y = this.or;
        var z = this.u0 || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            var aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.rk.ak = x;
                    this.rk.ag = x;
                    this.rk.al = z;
                    this.rk.ah = z;
                    this.rk.f = true;
                    if (p) {
                        this.sq(t, 0, s, u, v, b.q);
                    }
                    this.rk.ad(n, false, false, false, false);
                    n.am = this.rk.k;
                    n.an = this.rk.l;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.rk.ak = w;
                    this.rk.ag = w;
                    this.rk.al = y;
                    this.rk.ah = y;
                    this.rk.f = false;
                    if (p) {
                        this.sq(t, 0, s, u, v, b.q);
                    }
                    this.rk.ad(n, false, false, false, false);
                    n.am = this.rk.k;
                    n.an = this.rk.l;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (var ab = 1; ab < a.f.count; ++ab) {
            var ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            var ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.dg(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.rk.ak = w;
                this.rk.ag = w;
                this.rk.al = y;
                this.rk.ah = y;
                this.rk.f = false;
                if (l > ad) {
                    if (p) {
                        this.sq(t, ab, s, u, v, b.q);
                    }
                }
                else {
                    this.rk.ak = x;
                    this.rk.ag = x;
                    this.rk.al = z;
                    this.rk.ah = z;
                    this.rk.f = true;
                    if (p) {
                        this.sq(t, ab, s, u, v, b.q);
                    }
                }
                this.rk.ad(n, false, false, false, false);
                n.am = this.rk.k;
                n.an = this.rk.l;
                l = ad;
            }
        }
        m.count = o;
        b.cy(a);
    };
    Object.defineProperty(WaterfallSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.r7;
        },
        enumerable: false,
        configurable: true
    });
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    WaterfallSeries.$$p = markDep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:uz:uv', [Brush.$, null], 'NegativeOutline:u0:uw', [Brush.$, null], 'RadiusX:up:ux', [1, 0], 'RadiusY:uq:uy', [1, 0]]);
    return WaterfallSeries;
}(HorizontalAnchoredCategorySeries));
export { WaterfallSeries };
/**
 * @hidden
 */
var WaterfallSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesView, _super);
    function WaterfallSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.dc = null;
        _this.dj = new Rectangle();
        _this.db = null;
        _this.da = a;
        _this.db = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.dk);
            $ret.activate = runOn(_this, _this.dd);
            $ret.disactivate = runOn(_this, _this.df);
            $ret.destroy = runOn(_this, _this.de);
            return $ret;
        })());
        return _this;
    }
    WaterfallSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        this.dc = new List$1(Rectangle.$, 0);
        if (!this.q) {
            this.da.p0 = Defaults.c;
            this.da.gk = Defaults.h;
            this.da.gp = Defaults.i;
            this.da.uz = Defaults.ah;
            this.da.u0 = Defaults.ai;
        }
    };
    WaterfallSeriesView.prototype.dk = function () {
        var a = new Rectangle();
        this.dc.add(a);
        a._visibility = 1;
        return a;
    };
    WaterfallSeriesView.prototype.dd = function (a) {
        a._visibility = 0;
    };
    WaterfallSeriesView.prototype.df = function (a) {
        a._visibility = 1;
    };
    WaterfallSeriesView.prototype.de = function (a) {
        this.dc.remove(a);
    };
    WaterfallSeriesView.prototype.dg = function (a, b, c) {
        var d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.aq();
        }
    };
    WaterfallSeriesView.prototype.ac = function (a) {
        return this.dc._inner[a];
    };
    WaterfallSeriesView.prototype.ab = function (a) {
        var b = this.dc._inner[a];
        this.dj._visibility = b._visibility;
        this.dj.n = b.n;
        this.dj.o = b.o;
        this.dj.width = b.width;
        this.dj.height = b.height;
        var c = this.bp(a);
        this.dj._fill = c;
        this.dj._stroke = c;
        this.dj.ac = this.e.fn + 3;
        return this.dj;
    };
    WaterfallSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.dc.count; c++) {
                var d = this.aa(c, b);
                this.bd(d, c, b);
                a.v(d);
            }
        }
    };
    WaterfallSeriesView.prototype.al = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.al.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = __values(fromEnum(this.db.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = __values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                var f = "Negative";
                if (e._fill == this.e.oo) {
                    f = "Positive";
                }
                this.e.a7.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        b++;
    };
    WaterfallSeriesView.prototype.dh = function (a) {
        var b = this.db.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    };
    WaterfallSeriesView.prototype.di = function (a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    };
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
}(AnchoredCategorySeriesView));
export { WaterfallSeriesView };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/WaterfallSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { Brush } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { runOn, markType, markDep, fromEnum } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { Pool$1 } from "igniteui-react-core";
import { Rectangle } from "igniteui-react-core";
import { ArrayExtension } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
/**
 * @hidden
 */
var WaterfallSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeries, _super);
    function WaterfallSeries() {
        var _this = _super.call(this) || this;
        _this.ab = WaterfallSeries.$;
        return _this;
    }
    WaterfallSeries.prototype.get_ek = function () {
        return true;
    };
    WaterfallSeries.prototype.get_d2 = function () {
        return true;
    };
    WaterfallSeries.prototype.gu = function () {
        if (!isNaN_(this.gt)) {
            return _super.prototype.gu.call(this);
        }
        return Defaults.h;
    };
    WaterfallSeries.prototype.get_dt = function () {
        return true;
    };
    WaterfallSeries.prototype.bx = function () {
        return new WaterfallSeriesView(this);
    };
    WaterfallSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.u7 = a;
    };
    WaterfallSeries.prototype.preferredCategoryMode = function (a) {
        return 2;
    };
    WaterfallSeries.prototype.get_d3 = function () {
        return true;
    };
    WaterfallSeries.prototype.mn = function (a, b) {
        _super.prototype.mn.call(this, a, b);
        this.vi = a;
        this.vj = b;
    };
    WaterfallSeries.prototype.o9 = function () {
        return this.vi;
    };
    WaterfallSeries.prototype.pa = function () {
        return this.vj;
    };
    WaterfallSeries.prototype.b3 = function () {
        if (this.b4 == 0) {
            return 2;
        }
        return _super.prototype.b3.call(this);
    };
    WaterfallSeries.prototype.get_c2 = function () {
        return true;
    };
    WaterfallSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case WaterfallSeries.$$p[3]:
            case WaterfallSeries.$$p[2]:
            case WaterfallSeries.$$p[0]:
            case WaterfallSeries.$$p[1]:
                this.mi(false);
                break;
        }
    };
    WaterfallSeries.prototype.ev = function (a, b) {
        if (this.ey(a, b)) {
            return true;
        }
        if (this.qg(a, b)) {
            return true;
        }
        return false;
    };
    WaterfallSeries.prototype.pv = function (a) {
        var _this = this;
        if (this.u7 == null || this.u7.db == null || this.u7.db.count == 0 || this.xAxis == null) {
            return Rect.empty;
        }
        var b = this.u7.db;
        var c = this.ph(a);
        var d = -1;
        var e = this.xAxis.cg;
        var f = this.pz.right * 2;
        if (e) {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.u7.di(g);
                return (f - c.x) < (f - (h.left + h.width / 2)) ? -1 : ((f - c.x) > (f - (h.left + h.width / 2)) ? 1 : 0);
            });
        }
        else {
            d = ArrayExtension.binarySearch$1(Rectangle.$, b, function (g) {
                var h = _this.u7.di(g);
                return c.x < (h.left + h.width / 2) ? -1 : (c.x > (h.left + h.width / 2) ? 1 : 0);
            });
        }
        if (d < 0) {
            d = ~d;
            d--;
        }
        if (d < 0) {
            d = 0;
        }
        if (d > b.count - 1) {
            d = b.count - 1;
        }
        var g = d;
        var h = d;
        if (g < 0) {
            g--;
        }
        if (h < b.count - 1) {
            h++;
        }
        var i = this.vk(g);
        var j = this.vk(d);
        var k = this.vk(h);
        var l = i.left + i.width / 2;
        var m = j.left + j.width / 2;
        var n = k.left + k.width / 2;
        var o = Math.abs(l - c.x);
        var p = Math.abs(m - c.x);
        var q = Math.abs(n - c.x);
        var r = i.containsPoint(c);
        var s = j.containsPoint(c);
        var t = k.containsPoint(c);
        if (p <= o && p <= q) {
            if (!e && t) {
                return k;
            }
            if (e && r) {
                return i;
            }
            return j;
        }
        if (o <= p && o <= q) {
            if (!e && s) {
                return j;
            }
            return i;
        }
        if (q <= p && q <= o) {
            if (e && s) {
                return j;
            }
            return k;
        }
        return Rect.empty;
    };
    WaterfallSeries.prototype.vk = function (a) {
        return this.u7.dh(a);
    };
    WaterfallSeries.prototype.rz = function () {
        return 1;
    };
    WaterfallSeries.prototype.kx = function (a, b) {
        _super.prototype.kx.call(this, a, b);
        this.u7.db.count = 0;
    };
    WaterfallSeries.prototype.get_ts = function () {
        return 1;
    };
    WaterfallSeries.prototype.ga = function () {
        return this.uo.k3(this.b0.bv, this.b0.bu, this.getEffectiveViewport1(this.b0));
    };
    WaterfallSeries.prototype.s7 = function (a, b) {
        var c = b;
        _super.prototype.s7.call(this, a, b);
        var d = b.bv;
        var e = b.bu;
        var f = this.getEffectiveViewport1(b);
        var g = this.uo.k3(d, e, f);
        var h = this.u8;
        var i = this.u9;
        var j;
        var k = this.tq(b);
        var l = NaN;
        var m = c.db;
        var n;
        var o = 0;
        this.rx.a0(this, this.sh(), runOn(this, this.ri), this.sp(b), this.sq(b));
        this.rx.r = this.u8;
        this.rx.s = this.u9;
        this.rx.k = this.u8;
        this.rx.l = this.u9;
        var p = false;
        var q = this.rx.b;
        if (q != null) {
            p = true;
        }
        var r = this.uo.cm;
        var s = this.valueColumn.count;
        var t = a.f;
        var u = this.uo;
        var v = new ScalerParams(0, d, e, this.uo.cg, f);
        var w = this.oz;
        var x = this.vi;
        var y = this.o2;
        var z = this.vj || y;
        if (a.f.count > 0) {
            j = a.f._inner[0][0] - 0.5 * g;
            var aa = a.f._inner[0][1];
            if (!isNaN_(aa)) {
                if (aa > k) {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, k);
                    n.width = g;
                    n.height = Math.abs(k - aa);
                    this.rx.ak = x;
                    this.rx.ag = x;
                    this.rx.al = z;
                    this.rx.ah = z;
                    this.rx.f = true;
                    if (p) {
                        this.s3(t, 0, s, u, v, b.q);
                    }
                    this.rx.ad(n, false, false, false, false);
                    n.am = this.rx.k;
                    n.an = this.rx.l;
                }
                else {
                    n = m.item(o);
                    o++;
                    c.dg(n, j, aa);
                    n.width = g;
                    n.height = Math.abs(aa - k);
                    this.rx.ak = w;
                    this.rx.ag = w;
                    this.rx.al = y;
                    this.rx.ah = y;
                    this.rx.f = false;
                    if (p) {
                        this.s3(t, 0, s, u, v, b.q);
                    }
                    this.rx.ad(n, false, false, false, false);
                    n.am = this.rx.k;
                    n.an = this.rx.l;
                }
                l = aa;
            }
            else {
                l = k;
            }
        }
        for (var ab = 1; ab < a.f.count; ++ab) {
            var ac = a.f._inner[ab];
            j = a.f._inner[ab][0] - 0.5 * g;
            var ad = ac[1];
            if (!isNaN_(ad)) {
                n = m.item(o);
                o++;
                c.dg(n, j, Math.min(l, ad));
                n.width = g;
                n.height = Math.abs(l - ad);
                this.rx.ak = w;
                this.rx.ag = w;
                this.rx.al = y;
                this.rx.ah = y;
                this.rx.f = false;
                if (l > ad) {
                    if (p) {
                        this.s3(t, ab, s, u, v, b.q);
                    }
                }
                else {
                    this.rx.ak = x;
                    this.rx.ag = x;
                    this.rx.al = z;
                    this.rx.ah = z;
                    this.rx.f = true;
                    if (p) {
                        this.s3(t, ab, s, u, v, b.q);
                    }
                }
                this.rx.ad(n, false, false, false, false);
                n.am = this.rx.k;
                n.an = this.rx.l;
                l = ad;
            }
        }
        m.count = o;
        b.cy(a);
    };
    Object.defineProperty(WaterfallSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.sk;
        },
        enumerable: false,
        configurable: true
    });
    WaterfallSeries.$t = markType(WaterfallSeries, 'WaterfallSeries', HorizontalAnchoredCategorySeries.$);
    WaterfallSeries.$$p = markDep(DependencyProperty, PropertyMetadata, WaterfallSeries, 'raisePropertyChanged', ['NegativeBrush:vi:ve', [Brush.$, null], 'NegativeOutline:vj:vf', [Brush.$, null], 'RadiusX:u8:vg', [1, 0], 'RadiusY:u9:vh', [1, 0]]);
    return WaterfallSeries;
}(HorizontalAnchoredCategorySeries));
export { WaterfallSeries };
/**
 * @hidden
 */
var WaterfallSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesView, _super);
    function WaterfallSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.da = null;
        _this.dc = null;
        _this.dj = new Rectangle();
        _this.db = null;
        _this.da = a;
        _this.db = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.dk);
            $ret.activate = runOn(_this, _this.dd);
            $ret.disactivate = runOn(_this, _this.df);
            $ret.destroy = runOn(_this, _this.de);
            return $ret;
        })());
        return _this;
    }
    WaterfallSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        this.dc = new List$1(Rectangle.$, 0);
        if (!this.q) {
            this.da.qd = Defaults.c;
            this.da.gz = Defaults.i;
            this.da.vi = Defaults.ah;
            this.da.vj = Defaults.ai;
        }
    };
    WaterfallSeriesView.prototype.dk = function () {
        var a = new Rectangle();
        this.dc.add(a);
        a._visibility = 1;
        return a;
    };
    WaterfallSeriesView.prototype.dd = function (a) {
        a._visibility = 0;
    };
    WaterfallSeriesView.prototype.df = function (a) {
        a._visibility = 1;
    };
    WaterfallSeriesView.prototype.de = function (a) {
        this.dc.remove(a);
    };
    WaterfallSeriesView.prototype.dg = function (a, b, c) {
        var d = false;
        if (a.o != c) {
            d = true;
            a.o = c;
        }
        if (a.n != b) {
            d = true;
            a.n = b;
        }
        if (d) {
            this.aq();
        }
    };
    WaterfallSeriesView.prototype.ac = function (a) {
        return this.dc._inner[a];
    };
    WaterfallSeriesView.prototype.ab = function (a) {
        var b = this.dc._inner[a];
        this.dj._visibility = b._visibility;
        this.dj.n = b.n;
        this.dj.o = b.o;
        this.dj.width = b.width;
        this.dj.height = b.height;
        var c = this.bp(a);
        this.dj._fill = c;
        this.dj._stroke = c;
        this.dj.ac = this.e.fu + 3;
        return this.dj;
    };
    WaterfallSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.dc.count; c++) {
                var d = this.aa(c, b);
                this.bd(d, c, b);
                a.v(d);
            }
        }
    };
    WaterfallSeriesView.prototype.al = function (a) {
        var e_1, _a, e_2, _b;
        _super.prototype.al.call(this, a);
        var b = 0;
        var c = new List$1(Rectangle.$, 0);
        try {
            for (var _c = __values(fromEnum(this.db.a)), _d = _c.next(); !_d.done; _d = _c.next()) {
                var d = _d.value;
                c.add(d);
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_d && !_d.done && (_a = _c.return))
                    _a.call(_c);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        c.aa(function (e, f) {
            if (e.n < f.n) {
                return -1;
            }
            else if (e.n > f.n) {
                return 1;
            }
            else {
                return 0;
            }
        });
        try {
            for (var _e = __values(fromEnum(c)), _f = _e.next(); !_f.done; _f = _e.next()) {
                var e = _f.value;
                var f = "Negative";
                if (e._fill == this.e.oz) {
                    f = "Positive";
                }
                this.e.a8.exportRectangleData(a, e, "column" + b, ["Main", f]);
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_f && !_f.done && (_b = _e.return))
                    _b.call(_e);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        b++;
    };
    WaterfallSeriesView.prototype.dh = function (a) {
        var b = this.db.item(a);
        return new Rect(0, b.n, b.o, b.width, b.height);
    };
    WaterfallSeriesView.prototype.di = function (a) {
        return new Rect(0, a.n, a.o, a.width, a.height);
    };
    WaterfallSeriesView.$t = markType(WaterfallSeriesView, 'WaterfallSeriesView', AnchoredCategorySeriesView.$);
    return WaterfallSeriesView;
}(AnchoredCategorySeriesView));
export { WaterfallSeriesView };
